@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 
 import six
 from django.core.exceptions import ImproperlyConfigured
-from django.utils.importlib import import_module
+from importlib import import_module
 
 from .conf import conf
 
