@@ -69,8 +69,8 @@ def templatize(src, origin=None):
 
             # Build a string that looks like a Python file that's ready to be
             # translated.
-            translatable = '\n'.join(['_("""{0}""")'.format(escape(string))
-                                      for string in strings])
+            translatable = '\n'.join(sorted('_("""{0}""")'.format(escape(string))
+                                            for string in strings))
 
             return translatable
 
